<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl
//
// Uzupełnienie od wersji 0.9.5:
// Konrad Roziewski <konrad#suwalki-com-pl>

$newtask_text = array (

'createnewtask'	=>	'Utwórz nowe zgłoszenie dla projektu',
'summary'	=>	'Skrócony opis',
'tasktype'	=>	'Typ zgłoszenia',
'category'	=>	'Kategoria',
'status'	=>	'Status',
'assignedto'	=>	'Przydzielone dla',
'noone'		=>	'Nikogo',
'operatingsystem'	=>	'System operacyjny',
'severity'	=>	'Ważność',
'reportedversion'	=>	'Dotyczy wersji',
'dueinversion'	=>	'Obecne do wersji',
'details'	=>	'Szczegóły',
'addanother'	=>	'Potem dodaj kolejne zgłoszenie',
'addthistask'	=>	'Dodaj zgłoszenie',
'nopermission'	=>	'Nie masz uprawnień do oglądania tej strony',

// Added in version 0.9.5

'notifyme'	=>	'Powiadom mnie, gdy zgłoszenie zostanie zmienione',
'priority'	=>	'Priorytet',
'undecided'	=>	'Nie zdecydowano',

);
// vim:fenc=utf-8:enc=utf-8
?>
